#### CHAPTER 1

# define working directory and libraries
setwd(“SET YOUR OWN PATH“)
library(foreign) #to load stata dataset

# load data - needs to be in Stata version 12 - doesn't work with 13
#  use Stata saveold command
ch1 <- read.dta("data_for_R_chapter_1.dta", convert.factors = FALSE)

# ch1 is imported as a data frame, where columns correspond to variable 
# and rows correspond to observations. You can explore the data frame using 
# 'head' (list top n observations), 'str' (display the structure) or 'summary' functions.
head(ch1)
str(ch1)
summary(ch1)

# Table 1.1
# Fit a linear model with reading scores as the dependent variable and 
# gender and parental occupational status as independent variables.

# lm is the R function to fit OLS regression. 
# The first argument is a 'formula', where '~' separates dependent variable from independent ones.
# The independent variables are listed with '+'. 
ols1_1 <- lm(z_read ~ male + pos, data = ch1)

# Output the summary of the linear model result. Columns correspond to 
# regression coefficient, standard error and p value for each of the 
# variables, as well as Constant (Intercept in R).
summary(ols1_1)

# Define regions as factors
ch1$region <- factor(ch1$region,
      levels = c("3601", "3602", "3603", "3604", "3605", "3606", "3607", "3608"),
      labels = c("ACT", "NSW", "VIC", "QLD", "SA", "WA", "TAS", "NT") )

# Table 1.2 - to do mean z_read by region
# Option 1: carry out analysis of variance and extract region-specific means from the
# resulting object
table1_2 <- aov(ch1$z_read ~ ch1$region)
summary(table1_2)
model.tables(table1_2, type = 'means')

# Option 2: A more direct way to calculate means or standard deviation (or any other statistics) 
# by group would be to use R's 'tapply' function. There are other, more direct ways of doing it, that would
# require installing additional packages (see plyr package). Using 'tapply' is R-base way of doing it.
# The 'tapply' function takes the following arguments: 1) input data, in this case z_read, 2) vector of
# indices over which to apply function (regions); 3) the function to be applied. Feel free to explore other
# 'apply' family functions, such as 'apply', 'lapply' or 'sapply'.
## To calculate mean by group
tapply(ch1$z_read, ch1$region, mean)
## To calculate standard deviation by group
tapply(ch1$z_read, ch1$region, sd)

# Plot a box and whiskers plot arranged by the region variable
boxplot(z_read ~ region, col=c("white","lightgray"),data=ch1)

# Table 1.3
# Tabulate number of students per region
table(ch1$region)
# Same as above, but in precent of total number of students
table(ch1$region) / length(ch1$region) * 100

# Table 1.4
# Add the region variable to the linear model. In this case ACT acts as a reference (intercept) level.
# You can change which region acts as a reference level using relevel function
# ch1$region <- relevel(ch1$region, ref = "ACT")
ols1_4 <- lm(z_read ~ region + male + pos, data = ch1)
summary(ols1_4)

# Table 1.5
# Fit separate linear models for each of the regions. The last argument in the lm function is the 'subset'
# argument and 'ch1$region == "ACT"' expression returns a logical vector, with TRUE values for 
# observations from "ACT" and FALSE values otherwise.
ols1_5a <- lm(z_read ~ male + pos, data = ch1, ch1$region == "ACT")
summary(ols1_5a)
ols1_5b <- lm(z_read ~ male + pos, data = ch1, ch1$region == "NSW")
summary(ols1_5b)
ols1_5c <- lm(z_read ~ male + pos, data = ch1, ch1$region == "VIC")
summary(ols1_5c)
ols1_5d <- lm(z_read ~ male + pos, data = ch1, ch1$region == "QLD")
summary(ols1_5d)
ols1_5e <- lm(z_read ~ male + pos, data = ch1, ch1$region == "SA")
summary(ols1_5e)
ols1_5f <- lm(z_read ~ male + pos, data = ch1, ch1$region == "WA")
summary(ols1_5f)
ols1_5g <- lm(z_read ~ male + pos, data = ch1, ch1$region == "TAS")
summary(ols1_5g)
ols1_5h <- lm(z_read ~ male + pos, data = ch1, ch1$region == "NT")
summary(ols1_5h)

# Table 1.6
# Add interaction term to the linear model. Interactions are specified with '*'.
ols1_6 <- lm(z_read ~ male * region + pos * region, data = ch1)
summary(ols1_6)


